![](OMEGA_core/logo.png)

The OMEGA package is a python based microscopic image analysis toolkit optimized for mycobacterial cells. Unlike other rod-shaped bacterial model organisms (*E.coli* or *B. subtilis*), mycobacterial cells are 
